@@ -6,4 +6,4 @@ import pop.hub
 def start():
     hub = pop.hub.Hub()
     hub.pop.sub.add(dyne_name="tree", omit_class=False)
-    hub.pop.tree.init.doc_cli()
+    hub.tree.init.doc_cli()
