@@ -11,6 +11,8 @@ CLI_CONFIG = {
         "action": "store_true",
     },
     "graph": {},
+    "graph_layout": {},
+    "hide": {"nargs": "*"},
     "pypaths": {"nargs": "*"},
 }
 
@@ -28,6 +30,14 @@ CONFIG = {
         "help": "Plugin to use for generating a graph, (I.E. 'simple', 'details', 'json')",
         "default": None,
     },
+    "graph_layout": {
+        "help": "They layout to use with the graph plugin",
+        "default": None,
+    },
+    "hide": {
+        "help": "Hide teh named node types from the graph. I.e. functions, contracts, variables",
+        "default": [],
+    },
 }
 
 DYNE = {
