@@ -24,6 +24,6 @@ def process_mod(
 
 
 def show(hub, tree: Dict[str, Any]):
-    outputter = getattr(hub, f"output.{hub.OPT.rend.output}.display")
-    rendered = outputter(tree)
+    outputter = hub.OPT.rend.output or "nested"
+    rendered = hub.output[outputter].display(tree)
     print(rendered)
