@@ -33,6 +33,6 @@ def process_mod(
 def show(hub, tree: Dict[str, Any]):
     simple_tree = hub.graph.init.recurse(tree)
 
-    outputter = getattr(hub, f"output.{hub.OPT.rend.output}.display")
-    rendered = outputter(simple_tree)
+    outputter = hub.OPT.rend.output or "nested"
+    rendered = hub.output[outputter].display(simple_tree)
     print(rendered)
